Learn R Programming

mousetRajectory (version 0.2.1)

mousetRajectory-package: mousetRajectory: Mouse Trajectory Analyses for Behavioural Scientists

Description

Helping psychologists and other behavioural scientists to analyze mouse movement (and other 2-D trajectory) data. Bundles together several functions that compute spatial measures (e.g., maximum absolute deviation, area under the curve, sample entropy) or provide a shorthand for procedures that are frequently used (e.g., time normalization, linear interpolation, extracting initiation and movement times). For more information on these dependent measures, see Wirth et al. (2020) tools:::Rd_expr_doi("10.3758/s13428-020-01409-0").

Arguments

Author

Maintainer: Roland Pfister moritz.schaaf@uni-trier.de (ORCID) [copyright holder]

Authors:

See Also