Learn R Programming

mousetRajectory (version 0.2.1)

index_max_acceleration: Time point of maximum acceleration

Description

Computes the index of the peak acceleration of a trajectory, defined by vectors of x and y coordinates, and assumed to be equidistant in time.

Usage

index_max_acceleration(x_vector, y_vector, absolute = FALSE)

Value

Single number indicating the index of peak acceleration (1 to +Inf).

Arguments

x_vector

x-coordinates of the executed path.

y_vector

y-coordinates of the executed path.

absolute

Should negative accelerations (i.e., deceleration) be included? Defaults to FALSE.

Details

The supplied vectors are assumed to be ordered by time with equal time differences.

References

Wirth, R., Foerster, A., Kunde, W., & Pfister, R. (2020). Design choices: Empirical recommendations for designing two-dimensional finger tracking experiments. Behavior Research Methods, 52, 2394 - 2416. tools:::Rd_expr_doi("10.3758/s13428-020-01409-0")

Examples

Run this code
x_vals <- c(0, 1, 2, 3, 6, 10, 12, 14, 15)
y_vals <- c(0, 0, 0, 0, 0, 0, 0, 0, 0)
index_max_acceleration(x_vals, y_vals)
# acceleration maximal between x_vals[4] and x_vals[5]

Run the code above in your browser using DataLab