Single number indicating the index of peak acceleration (1 to +Inf).
Arguments
x_vector
x-coordinates of the executed path.
y_vector
y-coordinates of the executed path.
absolute
Should negative accelerations (i.e., deceleration)
be included? Defaults to FALSE.
Details
The supplied vectors are assumed to be ordered by time with equal
time differences.
References
Wirth, R., Foerster, A., Kunde, W., & Pfister, R. (2020).
Design choices: Empirical recommendations for designing two-dimensional
finger tracking experiments. Behavior Research Methods, 52, 2394 - 2416.
tools:::Rd_expr_doi("10.3758/s13428-020-01409-0")